%define momorel 2
%define libmaj 0
%define libmin 9
%define librel 7
%define librev d

%define openssldir %{_datadir}/ssl

Summary: Secure Sockets Layer and cryptography libraries and tools
Name: openssl

Version: %{libmaj}.%{libmin}.%{librel}%{librev}
Release: %{momorel}m
License: BSD
Group: System Environment/Libraries
URL: http://www.openssl.org/

%NoSource 0 ftp://ftp.openssl.org/source/%{name}-%{version}.tar.gz 1b49e90fc8a75c3a507c0a624529aca5
Source1: Makefile.certificate
Source2: ca-bundle.crt
Source3: make-dummy-cert

Patch0: openssl-cflags.patch
Patch1: openssl-0.9.7a-missing-header.patch
Patch2: openssl-0.9.7d-pk7.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root

Provides: SSL

%description
The OpenSSL Project is a collaborative effort to develop a robust,
commercial-grade, fully featured, and Open Source toolkit implementing the
Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1)
protocols with full-strength cryptography world-wide. The project is
managed by a worldwide community of volunteers that use the Internet to
communicate, plan, and develop the OpenSSL tookit and its related
documentation.

OpenSSL is based on the excellent SSLeay library developed from Eric A.
Young and Tim J. Hudson.  The OpenSSL toolkit is licensed under an
Apache-style licence, which basically means that you are free to get and
use it for commercial and non-commercial purposes.

This package contains the base OpenSSL cryptography and SSL/TLS
libraries and tools.

%package devel
Summary: Secure Sockets Layer and cryptography static libraries and headers
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The OpenSSL Project is a collaborative effort to develop a robust,
commercial-grade, fully featured, and Open Source toolkit implementing the
Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1)
protocols with full-strength cryptography world-wide. The project is
managed by a worldwide community of volunteers that use the Internet to
communicate, plan, and develop the OpenSSL tookit and its related
documentation.

OpenSSL is based on the excellent SSLeay library developed from Eric A.
Young and Tim J. Hudson.  The OpenSSL toolkit is licensed under an
Apache-style licence, which basically means that you are free to get and
use it for commercial and non-commercial purposes.

This package contains the the OpenSSL cryptography and SSL/TLS
static libraries and header files required when developing applications.

%prep

%setup -q
%patch0 -p1 -b .cflags
%patch1 -p1 -b .missing
%__perl -p -i -e "s|ln -s|cp|" util/point.sh
%patch2 -p0 -b .bug884

%build
%global _configure_args no-rc5 no-idea -DSSL_ALLOW_ADH
%append _configure_args -- --prefix=%{_prefix} --openssldir=%{openssldir}

FLAGS="$(echo '%{optflags}'| sed -e 's/-fstack-protector//')"
%global _configure_cmd ./config
%ifarch ppc
%append _configure_args -- -O0 -g -fsigned-char
%else
%ifarch alpha
%global _configure_cmd ./Configure
%append _configure_args -- $FLAGS linux-alpha-gcc
%else
%append _configure_args -- $FLAGS
%endif
%endif

%{_configure_cmd} %{_configure_args} shared
# parallel build may cause trouble?
make

make test

%install
[ "%{buildroot}" != "/" ] && %__rm -rf %{buildroot}
make install MANDIR=%{_mandir} INSTALL_PREFIX="%{buildroot}"
if [ -d %{buildroot}%{_libdir}/pkgconfig ]; then
  %__chmod +x %{buildroot}%{_libdir}/pkgconfig	# Workaround 0.9.7c's make install bug
fi

# Install a makefile for generating keys and self-signed certs, and a script
# for generating them on the fly.
%__mkdir_p %{buildroot}%{openssldir}/certs
%__install -m 644 %{SOURCE1} %{buildroot}%{openssldir}/certs/Makefile
%__install -m 644 %{SOURCE3} %{buildroot}%{openssldir}/certs/make-dummy-cert

# Install ca-bundle(from mod_ssl)
%__install -m 644 %{SOURCE2} %{buildroot}%{openssldir}/certs/
%__ln_s -f certs/ca-bundle.crt %{buildroot}%{openssldir}/cert.pem

# Rename manpages
%__mv %{buildroot}%{_mandir}/man7/Modes\ of\ DES.7 \
  %{buildroot}%{_mandir}/man7/Modes_of_DES.7
for x in %{buildroot}%{_mandir}/man*/*; do
  %__mv "${x}" "${x}ssl"
done

# Install RSAref stuff
# install -m644 rsaref/rsaref.h %{buildroot}/usr/include/openssl
# install -m644 libRSAglue.a %{buildroot}/usr/lib

# Make backwards-compatibility symlink to ssleay
%__ln_s -f %{_bindir}/openssl %{buildroot}%{_bindir}/ssleay

find %{buildroot}%{_libdir} -type f -a -name "lib*.so*" | \
  xargs %__chmod +x

%clean
[ "%{buildroot}" != "/" ] && %__rm -rf %{buildroot}

%files
%defattr(0644,root,root,0755)
%doc CHANGES CHANGES.SSLeay LICENSE NEWS README
%doc doc

%attr(0755,root,root) %{_bindir}/*
%attr(0755,root,root) %{_libdir}/*.so*
%attr(0755,root,root) %{openssldir}/misc/*
%attr(0644,root,root) %{openssldir}/certs/*
%attr(0644,root,root) %{openssldir}/cert.pem

%attr(0644,root,root) %{_mandir}/man[157]/*

%config %attr(0644,root,root) %{openssldir}/openssl.cnf
%dir %attr(0755,root,root) %{openssldir}/certs
%dir %attr(0755,root,root) %{openssldir}/lib
%dir %attr(0755,root,root) %{openssldir}/misc
%dir %attr(0750,root,root) %{openssldir}/private

%files devel
%defattr(0644,root,root,0755)
%doc LICENSE
%attr(0755,root,root) %dir %{_includedir}/openssl
%attr(0644,root,root) %{_includedir}/openssl/*
%attr(0644,root,root) %{_libdir}/*.a
%attr(0644,root,root) %{_mandir}/man[3]/*
%attr(0755,root,root) %{_libdir}/pkgconfig
%attr(0644,root,root) %{_libdir}/pkgconfig/openssl.pc

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%changelog
* Fri Jun 25 2004 TAKAHASHI Tamotsu <tamo>
- (0.9.7d-2m)
- apply http://cvs.openssl.org/filediff?f=openssl/crypto/pkcs7/pk7_doit.c&v1=1.50.2.8&v2=1.50.2.9
 see http://www.mail-archive.com/openssl-dev@openssl.org/msg17377.html
 You cannot S/MIME-encrypt messages without this patch!

* Wed Mar 17 2004 Kazuhiko <kazuhiko@fdiary.net>
- (0.9.7d-1m)
- including DoS fix
- http://www.openssl.org/news/secadv_20040317.txt

* Wed Dec 17 2003 YONEKAWA Susumu <yonekawa@mmg.roka.jp>
- (0.9.7c-5m)
- add openssl-0.9.7c-pod-fix.patch
  patch missing comma to doc/crypto/EVP_DigestInit.pod and doc/crypto/ui.pod
  This has already fixed in snapshot version
  http://www.mail-archive.com/openssl-dev@openssl.org/msg16352.html

* Mon Oct 27 2003 Kenta MURATA <muraken2@nifty.com>
- (0.9.7c-4m)
- devel package includes LICENSE.
- pretty spec file.

* Tue Oct 7 2003 Kazuhiko <yohgaki@momonga-linux.org>
- (0.9.7c-3m)
- add openssl.pc 

* Sun Oct  5 2003 Kazuhiko <kazuhiko@fdiary.net>
- (0.9.7c-2m)
- mv Modes\ of\ DES.7 Modes_of_DES.7

* Tue Sep 30 2003 zunda <zunda at freeshell.org>
- (0.9.7c-1m)
- [security] fix for DOS and remote code execution vulnerability
  http://www.uniras.gov.uk/vuls/2003/006489/openssl.htm

* Mon Jul 28 2003 Masahiro Takahata <takahata@momonga-linux.org>
- (0.9.7b-2m)
- modify %define openssldir %{_datadir}/ssl

* Mon Apr 14 2003 HOSONO Hidetomo <h12o@h12o.org>
- (0.9.7b-1m)
- remove openssl-TimingAttack.patch (Patch2)
  and openssl-0.9.7a-Klima_Pokorny_Rosa.patch (Patch3)

* Sun Mar 23 2003 KOMATSU Shinichiro <koma2@momonga-linux.org>
- (0.9.7a-4m)
- [security] Klima-Pokorny-Rosa attack on RSA in SSL/TLS
  http://www.openssl.org/news/secadv_20030319.txt

* Tue Mar 18 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (0.9.7a-3m)
  fix symbolic link
  security fix
  http://www.securityfocus.com/archive/1/315292/2003-03-15/2003-03-21/0
  http://www.openssl.org/news/secadv_20030317.txt

* Sun Mar  8 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (0.9.7a-2m)
  add bn_lcl.h

* Wed Mar  5 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (0.9.7a-1m)
  update to 0.9.7a

* Thu Feb 20 2003 HOSONO Hidetomo <h12o@h12o.org>
- (0.9.6i-1m)
- version up

* Sat Dec  7 2002 HOSONO Hidetomo <h12o@h12o.org>
- (0.9.6h-1m)
- version up

* Tue Dec  3 2002 Kazuhiko <kazuhiko@fdiary.net>
- (0.9.6g-3m)
- drop '-fstack-protector' instead of '-fomit-frame-pointer'

* Tue Dec  3 2002 YAMAZAKI Makoto <uomaster@nifty.com>
- (0.9.6g-2m)
- drop -fomit-frame-pointer to resolve [Momonga-devel.ja:00956]

* Mon Aug 12 2002 Shigeyuki Yamashita <shige@cty-net.ne.jp>
- (0.9.6g-1m)
- update to 0.9.6g

* Wed Aug  7 2002 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (0.9.6e-2m)
- [security] Add Patch10 (openssl-0.9.6e-asn1.diff)
  This patch fixes the ASN.1 vulnerability.
  Ref. http://rhn.redhat.com/errata/RHSA-2002-160.html
- on alpha*, do not use ./config, use ./Configure instead,
  because shared library is not built if ccc is installed.
- delete Patch1 (openssl-alphaev5.patch)
  since ./config is no longer used on alpha*
- modify openssl-cflags.patch so as to
  make command line arguments have higher priority
  than ./Configure's default one.
- modify openssl-cflags.patch to build on sparc
  (assembler is disabled).

* Tue Jul 30 2002 HOSONO Hidetomo <h@h12o.org>
- (0.9.6e-1m)
- version up (openssl-0.9.6e includes a security fix)
- a fix of openssl-cflags.patch

* Fri May 17 2002 HOSONO Hidetomo <h@kondara.org>
- (0.9.6d-4k)
- a fix of openssl-cflags.patch
  and openssl-0.9.6d-Configure.patch is not needed(...).

* Wed May 15 2002 HOSONO Hidetomo <h@kondara.org>
- (0.9.6d-2k)
- update to 0.9.6d
- update openssl-cflags.patch
- add openssl-0.9.6d-Configure.patch for Configure script bug fix

* Fri Mar  8 2002 Tsutomu Yasuda <tom@kondara.org>
- (0.9.6c-2k)
- update to 0.9.6c

* Thu Nov  8 2001 Masahiro Takahata <takahata@kondara.org>
- (0.9.6b-6k)
- import from rawhide(Makefile.certificate make-dummy-cert)
- import from mod_ssl(ca-bundle.crt)

* Mon Aug  3 2001 Toru Hoshina <toru@df-usa.com>
- (0.9.6b-4k)
- force ev5 for alphaev5.

* Sun Jul 15 2001 MATSUDA, Daiki <dyky@df-usa.com>
- (0.9.6b-2k)
- update to 0.9.6b for security fix

* Wed Apr 11 2001 Tsutomu Yasuda <tom@digitalfactory.co.jp>
- update to 0.9.6a

* Thu Oct 12 2000 Tsutomu Yasuda <tom@digitalfactory.co.jp>
- update to 0.9.6
- no-rc5 no-idea
* Wed Apr 19 2000 Tenkou N. Hattori <tnh@kondara.org>
- kondarize.
* Sun Feb 27 2000 Damien Miller <djm@mindrot.org>
- Merged patches to spec
- Updated to 0.9.5beta2 (now with manpages)
* Sat Feb  5 2000 Michal Jaegermann <michal@harddata.com>
- added 'linux-alpha' to configuration
- fixed nasty absolute links
* Tue Jan 25 2000 Bennett Todd <bet@rahul.net>
- Added -DSSL_ALLOW_ADH, bumped Release to 4
* Thu Oct 14 1999 Damien Miller <djm@mindrot.org>
- Set default permissions
- Removed documentation from devel sub-package
* Thu Sep 30 1999 Damien Miller <djm@mindrot.org>
- Added "make test" stage
- GPG signed
* Tue Sep 10 1999 Damien Miller <damien@ibs.com.au>
- Updated to version 0.9.4
* Tue May 25 1999 Damien Miller <damien@ibs.com.au>
- Updated to version 0.9.3
- Added attributes for all files
- Paramatised openssl directory
* Sat Mar 20 1999 Carlo M. Arenas Belon <carenas@jmconsultores.com.pe>
- Added "official" bnrec patch and taking other out
- making a link from ssleay to openssl binary
- putting all changelog together on SPEC file
* Fri Mar  5 1999 Henri Gomez <gomez@slib.fr>
- Added bnrec patch
* Tue Dec 29 1998 Jonathan Ruano <kobalt@james.encomix.es>
- minimum spec and patches changes for openssl
- modified for openssl sources
* Sat Aug  8 1998 Khimenko Victor <khim@sch57.msk.ru>
- shared library creating process honours %{optflags}
- shared libarry supports threads (as well as static library)
* Wed Jul 22 1998 Khimenko Victor <khim@sch57.msk.ru>
- building of shared library completely reworked
* Tue Jul 21 1998 Khimenko Victor <khim@sch57.msk.ru>
- RPM is BuildRoot'ed
* Tue Feb 10 1998 Khimenko Victor <khim@sch57.msk.ru>
- all stuff is moved out of /usr/local
